@@ -6,6 +6,7 @@ from math import isclose, isfinite
 from zlib import compress
 
 import pytest
+from conftest import skip_if_pypy
 from hypothesis import assume, example, given
 from hypothesis.strategies import (
     binary,
@@ -159,6 +160,7 @@ def test_list_apis():
     assert a == pikepdf.Array([1, Name.Foo, 4, 42, 666])
 
 
+@skip_if_pypy
 def test_stack_depth():
     a = [42]
     for _ in range(100):
@@ -592,3 +594,14 @@ def test_stream_dict_oneshot():
     assert stream1.read_bytes() == b'12345'
     assert stream2.Three == 3
     assert stream3.One == 1
+
+
+def test_dict_bad_params():
+    with pytest.raises(ValueError):
+        Dictionary({'/Foo': 1}, Bar=2)
+
+
+def test_stream_bad_params():
+    p = pikepdf.new()
+    with pytest.raises(TypeError, match='data'):
+        Stream(p)
